<?php
/**
 * Tish4 functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 */

function tish4_enqueue_styles() {

	wp_enqueue_style( 'tish1-stylesheet', get_template_directory_uri() . '/style.css' );
	wp_enqueue_style( 'tish4-child-style', get_stylesheet_uri(), array( 'tish4-stylesheet' ) );
}
add_action( 'wp_enqueue_scripts', 'tish4_enqueue_styles' );


if ( ! class_exists( 'tish4_Customize' ) ) :
	/**
	 * Singleton class for handling the theme's customizer integration.
	 */
	final class tish4_Customize {

		// Returns the instance.
		public static function get_instance() {

			static $instance = null;

			if ( is_null( $instance ) ) {
				$instance = new self;
				$instance->setup_actions();
			}

			return $instance;
		}

		// Constructor method.
		private function __construct() {}

		// Sets up initial actions.
		private function setup_actions() {

			// Register panels, sections, settings, controls, and partials.
			add_action( 'customize_register', array( $this, 'sections' ) );

			// Register scripts and styles for the controls.
			add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
		}

		// Sets up the customizer sections.
		public function sections( $manager ) {

			// Load custom sections.

			// Register custom section types.
			$manager->register_section_type( 'tish1_Customize_Section_Pro' );

			// Register sections.
			$manager->add_section(
				new tish1_Customize_Section_Pro(
					$manager,
					'tish4',
					array(
						'title'    => esc_html__( 'Tish4Pro', 'tish4' ),
						'pro_text' => esc_html__( 'Upgrade', 'tish4' ),
						'pro_url'  => esc_url( 'https://tishthemes.com/product/tish4pro' )
					)
				)
			);
		}

		// Loads theme customizer CSS.
		public function enqueue_control_scripts() {

			wp_enqueue_script( 'tish1-customize-controls', trailingslashit( get_template_directory_uri() ) . 'js/customize-controls.js', array( 'customize-controls' ) );

			wp_enqueue_style( 'tish1-customize-controls', trailingslashit( get_template_directory_uri() ) . 'css/customize-controls.css' );
		}
	}
endif; // tish4_Customize

// Doing this customizer thang!
tish4_Customize::get_instance();

/**
 * Remove Parent theme Customize Up-Selling Section
 */
if ( ! function_exists( 'tish4_remove_parent_theme_upsell_section' ) ) :

	function tish4_remove_parent_theme_upsell_section( $wp_customize ) {

		// Remove Parent-Theme Upsell section
		$wp_customize->remove_section('tish1');
	}

endif; // tish4_remove_parent_theme_upsell_section

add_action( 'customize_register', 'tish4_remove_parent_theme_upsell_section', 100 );
